@@ -1,16 +1,12 @@
 """
 Find native and alien observations of marine species.
+
 It finds species data from OBIS and connect to distribution of the species
 using WoRMS, GISD and Molnar data sources. It uses geo-spatial regions
 based on MEOW ECOS merged with MRGID (used by WoRMS source) from different
 shape-files.
 
-All modules logs all activities to marine_invaders.log file.
-Some Exceptions are also logged and passed for convenient. F.e.
-if request to WoRMS API returns some error (no data found f.e.)
-the whole process does nto stop but the event is logged as error.
-
-@author radek.lonka@ntnu.no
+More about data processing can be found at README.md
 """
 
 
@@ -33,7 +29,7 @@ from marinvaders.observation import observations
 # ignoring UserWarnings when using str.contains in Species.gisd() method
 warnings.filterwarnings("ignore", 'This pattern has match groups')
 
-log_filename = 'marine_invaders.log'
+log_filename = 'marinvaders.log'
 handlers = [logging.FileHandler(log_filename)]
 
 logging.basicConfig(level=logging.DEBUG,
